==> Devel-Kit-0.4.tar.gz: Devel-Kit-0.4/lib/Devel/Kit/cPanel.pm <==
package Devel::Kit::cPanel;

use strict;
use warnings;
$Devel::Kit::cPanel::VERSION = '0.1';

use base 'Devel::Kit';
@Devel::Kit::cPanel::ISA = ('Devel::Kit');

sub import {
    my $caller = caller();
    require Import::Into;    # die here since we don't need it otherwise, so we know right off there's a problem, and so caller does not have to check status unless they want to
    Devel::Kit->import::into( $caller, @_ );
}

use Cpanel::Logger ();
my $logger = Cpanel::Logger->new();

{
    no warnings 'redefine';
    *Devel::Kit::o = sub {
        unshift @_, $logger;
        goto &Cpanel::Logger::info;
    };
}

1;

__END__

=encoding utf-8

=head1 NAME

Devel::Kit::cPanel - cPanel friendly version of Devel::Kit (A handy toolbox of things to ease development/debugging).

=head1 VERSION

This document describes Devel::Kit::cPanel version 0.1

=head1 SYNOPSIS

    use Devel::Kit::cPanel; # strict and warnings are now enabled
    
    d($something); # d() and some other useful debug/dump functions are now availble!

=head1 DESCRIPTION

cPanel friendly (via Cpanel::Logger->info()) version of L<Devel::Kit>.

See L<Devel::Kit> for details.

=head1 INCOMPATIBILITIES

None reported.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests to
C<bug-devel-kit@rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org>.

=head1 AUTHOR

Daniel Muey  C<< <http://drmuey.com/cpan_contact.pl> >>

=head1 LICENCE AND COPYRIGHT

Copyright (c) 2012, Daniel Muey C<< <http://drmuey.com/cpan_contact.pl> >>. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself. See L<perlartistic>.

=head1 DISCLAIMER OF WARRANTY

BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
NECESSARY SERVICING, REPAIR, OR CORRECTION.

IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
SUCH DAMAGES.

==> Devel-Kit-0.7.tar.gz: Devel-Kit-0.7/lib/Devel/Kit/cPanel.pm <==
package Devel::Kit::cPanel;

use strict;
use warnings;
$Devel::Kit::cPanel::VERSION = '0.1';

use base 'Devel::Kit';
@Devel::Kit::cPanel::ISA = ('Devel::Kit');

sub import {
    my $caller = caller();
    require Import::Into;    # die here since we don't need it otherwise, so we know right off there's a problem, and so caller does not have to check status unless they want to
    Devel::Kit->import::into( $caller, @_ );
}

use Cpanel::Logger ();
my $logger = Cpanel::Logger->new();

my $a;
{
    no warnings 'redefine';
    *Devel::Kit::o = sub {
        unshift @_, $logger;
        goto &Cpanel::Logger::info;
    };

    *Devel::Kit::a = sub {
        if ( !$ak ) {
            require App::Kit::cPanel;
            $ak = App::Kit::cPanel->instance;
        }
        return $ak;
    };
}

1;

__END__

=encoding utf-8

=head1 NAME

Devel::Kit::cPanel - cPanel friendly version of Devel::Kit (A handy toolbox of things to ease development/debugging).

=head1 VERSION

This document describes Devel::Kit::cPanel version 0.1

=head1 SYNOPSIS

    use Devel::Kit::cPanel; # strict and warnings are now enabled
    
    d($something); # d() and some other useful debug/dump functions are now availble!

=head1 DESCRIPTION

cPanel friendly (via Cpanel::Logger->info()) version of L<Devel::Kit>.

See L<Devel::Kit> for details.

=head1 INCOMPATIBILITIES

None reported.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests to
C<bug-devel-kit@rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org>.

=head1 AUTHOR

Daniel Muey  C<< <http://drmuey.com/cpan_contact.pl> >>

=head1 LICENCE AND COPYRIGHT

Copyright (c) 2012, Daniel Muey C<< <http://drmuey.com/cpan_contact.pl> >>. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself. See L<perlartistic>.

=head1 DISCLAIMER OF WARRANTY

BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
NECESSARY SERVICING, REPAIR, OR CORRECTION.

IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
SUCH DAMAGES.
